@@ -20,7 +20,7 @@
 #include <KActionCollection>
 #include <KLocalizedString>
 #include <KScoreDialog>
-#include <KStandardGameAction>
+#include <KGameStandardAction>
 
 //generated
 #include "settings.h"
@@ -140,7 +140,7 @@ void KSquaresWindow::gameNew()
 void KSquaresWindow::gameReset()
 {
     //create players
-    QVector<KSquaresPlayer> playerList;
+    QList<KSquaresPlayer> playerList;
     for (int i = 0; i < Settings::numOfPlayers(); i++) {
         QColor color;
         switch (i) {
@@ -191,9 +191,9 @@ void KSquaresWindow::gameReset()
     sGame->start();
 }
 
-void KSquaresWindow::gameOver(const QVector<KSquaresPlayer> &_playerList)
+void KSquaresWindow::gameOver(const QList<KSquaresPlayer> &_playerList)
 {
-    QVector<KSquaresPlayer> playerList = _playerList;
+    QList<KSquaresPlayer> playerList = _playerList;
     std::sort(playerList.begin(), playerList.end(), std::greater<KSquaresPlayer>());
     //m_scene->displayScoreTable(playerList);
 
@@ -286,12 +286,12 @@ void KSquaresWindow::aiChooseLine()
 
 void KSquaresWindow::setupActions()
 {
-    KStandardGameAction::gameNew(this, &KSquaresWindow::gameNew, actionCollection());
-    QAction *resetGame = KStandardGameAction::restart(this, &KSquaresWindow::gameReset, actionCollection());
+    KGameStandardAction::gameNew(this, &KSquaresWindow::gameNew, actionCollection());
+    QAction *resetGame = KGameStandardAction::restart(this, &KSquaresWindow::gameReset, actionCollection());
     resetGame->setStatusTip(i18n("Start a new game with the current settings"));
 
-    KStandardGameAction::highscores(this, &KSquaresWindow::showHighscores, actionCollection());
-    KStandardGameAction::quit(this, &QWidget::close, actionCollection());
+    KGameStandardAction::highscores(this, &KSquaresWindow::showHighscores, actionCollection());
+    KGameStandardAction::quit(this, &QWidget::close, actionCollection());
 
     // Preferences
     KStandardAction::preferences(this, &KSquaresWindow::optionsPreferences, actionCollection());
